# Device Transfer

::: torchlinops.linops.ToDevice
    options:
        inherited_members: false
        members:
            - __init__
            - normal

::: torchlinops.linops.DeviceSpec
    options:
        inherited_members: false
        members:
            - __init__
            - p2p_setup
            - get_transfer_stream
